Module: AdLint
- Defined in:
- lib/adlint/postfilter/path.rb,
lib/adlint/postfilter/config.rb,
lib/adlint/postfilter/driver.rb,
lib/adlint/postfilter/filter.rb,
lib/adlint/postfilter/command.rb,
lib/adlint/postfilter/content.rb,
lib/adlint/postfilter/version.rb,
lib/adlint/postfilter/annotate.rb,
lib/adlint/postfilter/suppress.rb
Overview
-- ___ ____ __ ___ _________ / | / _ |/ / / / | / /__ / Source Code Static Analyzer / /| | / / / / / / / |/ / / / AdLint - Advanced Lint / __ |/ // / // / /| / / / // ||//// |/ // Copyright (C) 2010-2012, OGIS-RI Co.,Ltd.
This file is part of adlint-postfilter.
adlint-postfilter is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
adlint-postfilter is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with adlint-postfilter. If not, see http://www.gnu.org/licenses/.
++
Defined Under Namespace
Modules: Postfilter